Name:           sigil
Version:        0.5.3
Release:        1%{?dist}
Summary:        WYSIWYG ebook editor

Group:          Applications/Productivity
License:        GPLv3+
URL:            http://code.google.com/p/sigil/
Source0:        http://sigil.googlecode.com/files/Sigil-%{version}-Code.zip

BuildRequires:  qt4-devel
BuildRequires:  qtwebkit-devel
BuildRequires:  boost-devel
BuildRequires:  zlib-devel
BuildRequires:  ZipArchive-devel
BuildRequires:  FlightCrew-devel
BuildRequires:  xerces-c-devel >= 3.1
BuildRequires:  hunspell-devel
BuildRequires:  pcre-devel

%description
Sigil is a multi-platform WYSIWYG ebook editor. It is designed to edit books
in ePub format.

Now what does it have to offer...

    * Full Unicode support: everything you see in Sigil is in UTF-16
    * Full EPUB spec support
    * WYSIWYG editing
    * Multiple Views: Book View, Code View and Split View
    * Metadata editor with full support for all possible metadata entries with
      full descriptions for each
    * Table Of Contents editor
    * Multi-level TOC support
    * Book View fully supports the display of any XHTML document possible under
      the OPS spec
    * SVG support
    * Basic XPGT support
    * Advanced automatic conversion of all imported documents to Unicode
    * Currently imports TXT, HTML and EPUB files; more will be added with time
    * Embedded HTML Tidy; all imported documents are thoroughly cleaned;
      changing views cleans the document so no matter how much you screw up
      your code, it will fix it (usually)
    * Native C++ application


%prep
%setup -q -c

# Fix EOL encoding for %%doc
for i in COPYING.txt ChangeLog.txt; do
    sed -i.old 's/\r//' "$i"
    touch -r "$i.old" "$i"
done

# remove unbundled stuff
for i in src/*; do
    # lets not remove Sigil itself ...
    if [ "$i" = "src/Sigil" ]; then
        continue
    fi
    # tidyLib is modified to deal with epub, so stick with the bundled copy
    if [ "$i" = "src/tidyLib" ]; then
        continue
    fi
    rm -r "$i"
done


%build
mkdir build
cd build
%{cmake} -G "Unix Makefiles" -DCMAKE_BUILD_TYPE=Release -DBUILD_SHARED_LIBS:BOOL=OFF ..
make %{?_smp_mflags}


%install
cd build
make install DESTDIR=$RPM_BUILD_ROOT


%files
%doc COPYING.txt ChangeLog.txt
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png


%changelog

* Sat Feb 25 2012 - 0.5.3-1
- Fix issue 1254: Bulk rename will stop if one name matches, context menu
 needs cleanup and warnings.
- Fix issue 1268: Find/Replace all files does not search in book order,
 and other issues.
- Fix issue 1266: Store user dictionary as UTF-8.
- Ensure the checkmarks in add semantic are set correctly when selecting
 multiple files.
- Fix issue 1030: Don't close if canceling out of a failed save.
- Fix issue 1258: Find/Replace step by step in All HTML files is broken.

* Thu Feb 09 2012 - 0.5.2-1
- Fix issue 1253: Replace All in All HTML files adds extra blank lines in
 style section.
- Fix issue 1251: Merge does not work if you previously used split chapter.
- Fix issue 1249: Replace All in All HTML Files leaves cursor at the
 bottom.
- Fix issue 1247: Cannot rename file extension in book browser and rename
 selected should default to first extension name.
- Fix issue 1238: Deleting a file does not go to the next closest entry
 in book browser.
- Fix issue 1236: Replace All in Current file does not center cursor.
- Fix issue 1234: Switching from Code View to Split View and SplitCV to
 CV does not vertically center the cursor.
- Fix issue 1237: Rename does not keep current selection in book browser.
- Fix issue 1242: Metadata::FreeFormMetadata missing assignment line 360.
- Fix issue 1235: Deleting one file does not give a warning dialog.
- Fix issue 1129: Crash when importing existing image.

* Sun Feb 05 2012 - 0.5.1-1
- Issue 1225:
 * Add searching selected files.
 * Add search wrapping.
 * Replace in BV automatically goes to CV.
 * Fixed bug where in CV if you do a replace of a word and then replace
   all when there are the same words on the page, the page view wouldn't
   be refreshed.
 * Various fixes.
- Add English translation file used for plural strings.
- Implement issue 986: Automatically renumber playorder in TOC NCX.
- Implement issue 1224: F&R modifications to update layout and add Regex Multiline.
- Fix issue 1214: Dictionary files do not include hypen files or GB files.
- Fix issue 1213: Find and Replace does not save file when F&R is already
 open and searching all HTML files.
- Remove the ability to use F&R to replace text in BV as it is unfixable in
 its current state.
- Fix issue 1215: Book View line/column incorrect in status bar.
- Fix issue 1216: Re-opening a document already in a tab resets the cursor
 position back to the top.
- Fix issue 1218: F&R cleanup.
- Fix issue 1212: Remove opf namespace rewriting when opening a file because
 it ended up being more trouble than it was wroth.
- Fix issue 1188: New Sigil Regex engine crashes when pressing "replace all",
 works fine on pushing "replace" over and over and over again.
- Implement issue 269: Select more than one item in the Book Browser Column.
- Implement issues 792: Add Shortcuts for next/previous HTML file with regard
 to reading order, and sync selection in book browser to open tab.
- Implement issue 1135: New blank section must be automatically selected on book browser.
- Implement issue 1148: Allow user to change the order of split view so book view or code
 view is first.
- Implement issue 1168: Add ability to sort HTML files alphanumerically.
- Implement issue 1174: Add new blank html section should insert section after selected file.
- Implement issue 1181: Merge Previous when previous file is open in current tab requires
 refresh to see merged data.

* Mon Jan 23 2012 Hans de Goede <hdegoede@redhat.com> - 0.5.0-1
- New upstream release 0.5.0
- Add patches to use system hunspell and pcre libs

* Thu Jan 12 2012 Hans de Goede <hdegoede@redhat.com> - 0.4.2-3
- Drop buildroot and defattr boilerplate (no longer needed with recent rpm)
- Use system FlightCrew and XercesExtensions
- Drop support for building for F-15, having a buildin xerces-c with a shared
  system XercesExtensions is asking for trouble

* Tue Dec 13 2011 Dan Horák <dan[at]danny.cz> - 0.4.2-2
- don't require SSE2 in xerces

* Mon Dec 12 2011 Dan Horák <dan[at]danny.cz> - 0.4.2-1
- initial Fedora version
